Home-Assistant ffmpeg interface
============
A python library that handling with ffmpeg for home-assistant Async

- Emulate webcam from any video input source for HA
- Analyse a video/audio stream for noise or motion detection
- Grab image from a stream

Be carfully that you protect function calls with `asyncio.shield`.

Links
-----
- http://home-assistant.io
